'use strict';

process.env.LOGGLY_SUBDOMAIN = 'test-subdomain';
process.env.LOGGLY_TOKEN = 'test-token';

var assert   = require('assert');
var sinon    = require('sinon');
var loggly   = require('loggly');
var logglyfy = require('./index');

describe('logglyfy object', function () {
  it('should expose loggly', function () {
    assert(logglyfy.loggly instanceof loggly.Loggly);
  });

  it('should have 4 log levels', function () {
    assert.equal(typeof logglyfy.debug, 'function');
    assert.equal(typeof logglyfy.info,  'function');
    assert.equal(typeof logglyfy.warn,  'function');
    assert.equal(typeof logglyfy.error, 'function');
  });

  it('should alias info with log', function () {
    assert.equal(typeof logglyfy.log, 'function');
    // assert.equal(logglyfy.log, logglyfy.info);
  });

  it('should expose core Loggly functions', function () {
    assert.equal(typeof logglyfy.search,    'function');
    assert.equal(typeof logglyfy.logglyUrl, 'function');
    assert.equal(typeof logglyfy.customer,  'function');
    assert.equal(typeof logglyfy.tagFilter, 'function');
  });

  ['log', 'debug', 'info', 'warn', 'error'].forEach(function (fn) {
    var level = fn === 'log' ? 'info' : fn;

    describe('#' + level + '()', function () {
      beforeEach(function () {
        sinon.stub(console, 'log');
      });

      afterEach(function () {
        console.log.restore();
      });

      it('should output to STDOUT', function () {
        // sinon.stub(logglyfy.loggly, 'log');

        logglyfy[fn].call(logglyfy, 'foo');

        sinon.assert.calledOnce(console.log);
        sinon.assert.calledWith(console.log, '[%s] foo', level);
        // sinon.assert.calledOnce(logglyfy.loggly.log);
      });

      it('should output to STDOUT with printf-styled params', function () {
        logglyfy[fn].call(logglyfy, 'foo%s!', 'bar');
        sinon.assert.calledOnce(console.log);
        sinon.assert.calledWith(console.log, '[%s] foo%s!', level, 'bar');
      });

      it('should output to STDOUT and send JSON to Loggly', function () {
        logglyfy[fn].call(logglyfy, 'foo');
        sinon.assert.calledOnce(console.log);
        sinon.assert.calledWith(console.log, '[%s] foo', level);
      });
    });
  });
});
